@@ -4,4 +4,7 @@
 from django.contrib import admin
 from coop_cms.apps.test_app import models
 
-admin.site.register(models.TestClass)
+
+@admin.register(models.TestClass)
+class TestClassAdmin(admin.ModelAdmin):
+    pass
